==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/lt/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Šis vartotojas gali prisijungti',
    'activated_disabled_help_text' => 'Jūs negalite keisti savosios pąskyros aktyvacijos statuso.',
    'assets_user'       => 'Priskirta įranga :name',
    'bulk_update_warn'	=> 'Jūs ketinate redaguoti vartotojų: user_count savybes. Atminkite, kad negalėsite pakeisti savo naudotojo atributų naudodami šią formą ir savo pasirinkimą keisti individualiai.',
    'bulk_update_help'	=> 'Ši forma leidžia vienu metu atnaujinti kelis naudotojus. Užpildykite tik tuos laukelius, kuriuos reikia keisti. Visi tušti laukai lieka nepakeisti.',
    'current_assets'    => 'Šiam vartotojui priskirta įranga',
    'clone'             => 'Kopijuoti naudotoją',
    'contact_user'      => 'Susisiekti su :name',
    'edit'              => 'Redaguoti naudotoją',
    'filetype_info'     => 'Leidžiami dokumentų formatai png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name naudotojo istorija',
	'info'				=> 'Informacija',
    'restore_user'		=> 'Spauskite čia norėdami juos atkurti.',
    'last_login'        => 'Paskutinis prisijungimas',
    'ldap_config_text'  => 'LDAP konfigūracijos parametrus galite rasti Administratorius> Nustatymai. Pasirinkta vieta (pasirinktinai) bus nustatyta visiems importuojamiems vartotojams.',
    'print_assigned'    => 'Spausdinti visą turtą',
    'software_user'     => ':name išduota įranga',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Peržiūrėti :name vartotoją',
    'usercsv'           => 'CSV dokumentas',
    'two_factor_admin_optin_help' => 'Dabartiniai jūsų nustatymai leidžia pasirinkti dviejų veiksnių autentifikavimą.',
    'two_factor_enrolled' => 'Įrašytas 2FA įrenginys',
    'two_factor_active'   => '2FA aktyvus',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/lt/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Šis vartotojas gali prisijungti',
    'activated_disabled_help_text' => 'Jūs negalite keisti savosios pąskyros aktyvacijos statuso.',
    'assets_user'       => 'Priskirta įranga :name',
    'bulk_update_warn'	=> 'Jūs ketinate redaguoti vartotojų: user_count savybes. Atminkite, kad negalėsite pakeisti savo naudotojo atributų naudodami šią formą ir savo pasirinkimą keisti individualiai.',
    'bulk_update_help'	=> 'Ši forma leidžia vienu metu atnaujinti kelis naudotojus. Užpildykite tik tuos laukelius, kuriuos reikia keisti. Visi tušti laukai lieka nepakeisti.',
    'current_assets'    => 'Šiam vartotojui priskirta įranga',
    'clone'             => 'Kopijuoti naudotoją',
    'contact_user'      => 'Susisiekti su :name',
    'edit'              => 'Redaguoti naudotoją',
    'filetype_info'     => 'Leidžiami dokumentų formatai png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name naudotojo istorija',
    'info'				=> 'Informacija',
    'restore_user'		=> 'Spauskite čia norėdami juos atkurti.',
    'last_login'        => 'Paskutinis prisijungimas',
    'ldap_config_text'  => 'LDAP konfigūracijos parametrus galite rasti Administratorius> Nustatymai. Pasirinkta vieta (pasirinktinai) bus nustatyta visiems importuojamiems vartotojams.',
    'print_assigned'    => 'Spausdinti visą turtą',
    'software_user'     => ':name išduota įranga',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Peržiūrėti :name vartotoją',
    'usercsv'           => 'CSV dokumentas',
    'two_factor_admin_optin_help' => 'Dabartiniai jūsų nustatymai leidžia pasirinkti dviejų veiksnių autentifikavimą.',
    'two_factor_enrolled' => 'Įrašytas 2FA įrenginys',
    'two_factor_active'   => '2FA aktyvus',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
